//   -*- mode: c++; -*-

const int MAX_BUF=10240;

#define COMMAND_VAR "command"
#define ICON_VAR    "icon"
#define NEEDS_VAR   "needs"
#define SECTION_VAR "section"
#define SORT_VAR    "sort"
#define TITLE_VAR   "title"
#define HOTKEY_VAR  "hotkey"
#define PRIVATE_ENTRYCOUNT_VAR "__PRIVATE__ENTRYCOUNT"
#define PRIVATE_ENTRYINDEX_VAR "__PRIVATE__ENTRYINDEX"

//conditionals in the menuentry files (like "package(vi)")
#define COND_PACKAGE "package"


#define COMPAT_MODE  "menu-1"


